from p_listener import sio

@sio.event
def runTask(data):
  func = data['func']
  args = data['args']

  possibles = globals().copy()
  possibles.update(locals())
  method = possibles.get(func)
  if not method:
      raise NotImplementedError("Method %s not implemented" % func)
  method(args)

def install(a):
  print("In install")
  print(a)



from distutils.core import setup

setup(
  name = 'pynodelayer',
  packages = ['pynodelayer'],
  version = '0.1',
  license='MIT',
  description = 'PyNode Layer library',
  author = 'Morteza Jamali',
  author_email = 'mortezajamali4241@gmail.com',
  url = 'https://github.com/Electron-OS/pynodelayer',
  download_url = 'https://github.com/Electron-OS/pynodelayer/archive/v0.0.1-alpha.tar.gz',
  keywords = ['System' , 'Linux' , 'Library' , 'pynodelayer' , 'socket layer'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)